# Fit Market Parameters

This module provides utilities to fit market-implied parameters from option prices.

### Fit Rate and Dividend

::: src.optpricing.calibration.fit_market_params.fit_rate_and_dividend

### Find ATM Options

::: src.optpricing.calibration.fit_market_params.find_atm_options
